# ContinentInfo
----

![](https://forthebadge.com/images/badges/made-with-python.svg)


ContinentInfo is python package to get the name of the continent in which a country is located in.

### Installation

ContinentInfo requires minimum [Python 2.7](https://www.python.org/downloads/release/python-272/) to run.

```sh
$ pip install ContinentInfo
```
### Usage
```sh
$ from ContinentInfo import get_continent
$ country_name = get_continent('India')
$ country_name
$ 'Asia'
```

### License
[![MIT license](http://img.shields.io/badge/license-MIT-brightgreen.svg)](http://opensource.org/licenses/MIT)

**Copyright (c) 2019 Rohit Swami**

This project is licensed under the MIT License - see the LICENSE.txt file for details
